@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
-# Copyright (C) 2019-2020 Colin B. Macdonald
+# Copyright (C) 2019-2021, 2023 Colin B. Macdonald
 # Copyright (C) 2020 Dryden Wiebe
 
 from io import StringIO
@@ -24,14 +24,14 @@ Jane Smith,43,12345679,ABCDEFGHIJ02,Math 123 S102v,12345679,919005618467
 """
     infile = StringIO(s1)
     outfile = StringIO("")
-    sns = canvas_csv_add_return_codes(infile, outfile, saltstr="default", digits=12)
+    _ = canvas_csv_add_return_codes(infile, outfile, saltstr="default", digits=12)
     s = outfile.getvalue()
     assert s == s2 or s.replace("\r\n", "\n") == s2
 
     # return codes already exist
     infile = StringIO(s2)
     outfile = StringIO("")
-    sns = canvas_csv_add_return_codes(infile, outfile, saltstr="default", digits=12)
+    _ = canvas_csv_add_return_codes(infile, outfile, saltstr="default", digits=12)
     s = outfile.getvalue()
     assert s == s2 or s.replace("\r\n", "\n") == s2
 
@@ -54,7 +54,7 @@ D Smith,45,12346666,ABCDEFGHIJ04,104,12346666,149766785804
 """
     infile = StringIO(s1)
     outfile = StringIO("")
-    sns = canvas_csv_add_return_codes(infile, outfile, saltstr="default", digits=12)
+    _ = canvas_csv_add_return_codes(infile, outfile, saltstr="default", digits=12)
     s = outfile.getvalue()
     assert s == s2 or s.replace("\r\n", "\n") == s2
 
@@ -96,7 +96,7 @@ def test_csv_missing_header_SIS_User_ID():
 
 
 def test_csv_cantfind_return_code():
-    infile = StringIO("""Student,SIS User ID,Retrun C0de ()""")
+    infile = StringIO("""Student,SIS User ID,R3trun C0de ()""")
     outfile = StringIO("")
     raises(
         AssertionError,
